@@ -8,12 +8,11 @@ from django.contrib.sites.models import Site
 from django.utils.translation import ugettext_lazy as _
 from django.template.loader import render_to_string
 
+
 class AllFeed(Feed):
 
     """
-    Clase de feeds en general (http://dominio.com/feed/)
-    Referencias:
-    - http://docs.djangoproject.com/en/dev/ref/contrib/syndication/?from=olddocs
+    - http://docs.djangoproject.com/en/dev/ref/contrib/syndication/
     - http://www.andrlik.org/writing/2007/aug/03/fun-with-django-feeds/
     """
 
@@ -30,7 +29,7 @@ class AllFeed(Feed):
         self.blogurl = "%s%s" % (prefix, self.current_site.domain)
 
     def items(self):
-        return Post.objects.all().filter(status=1).order_by('-creation_date')[:5]
+        return Post.objects.filter(status=1).order_by('-creation_date')[:5]
 
     def item_title(self, item):
         return item.title
@@ -42,19 +41,20 @@ class AllFeed(Feed):
         return self.blogurl + item.get_absolute_url()
 
     def item_description(self, item):
-
+        mylink = self.blogurl + item.get_absolute_url()
         rendered = render_to_string('rblog/footerfeed.html',
-                                    {'link': self.blogurl + item.get_absolute_url(),
+                                    {'link': mylink,
                                      'title': item.title,
-                                     'linkblog':self.blogurl,
-                                     'blog':conf.SITE_TITLE})
+                                     'linkblog': self.blogurl,
+                                     'blog': conf.SITE_TITLE})
 
         return item.text + rendered
 
+
 class TagFeed(Feed):
 
     """
-    Clase de feeds para los tags (http://dominio.com/tag-elquesea/feed/)
+    Tag feeds (http://domain.com/tag-whatever/feed/)
     """
 
     title = conf.SITE_TITLE
