@@ -16,10 +16,11 @@ from django.conf import settings as conf
 from django.core.urlresolvers import reverse
 from django.contrib.sites.models import Site
 
+
 class Post(models.Model):
 
     """
-    Modelo que define un post.
+    Post model
     """
 
     title = models.CharField(_(u'Title'), max_length=255)
@@ -31,10 +32,10 @@ class Post(models.Model):
     hits = models.IntegerField(_(u'Hits'), blank=True, default=1)
     creation_date = models.DateTimeField(_(u'Creation date'))
     user = models.ForeignKey(User, related_name="post_from")
-    highlighted =  models.BooleanField(_(u'Highlighted'), blank=True)
-    status =  models.BooleanField(_(u'Status'), default=True)
+    highlighted = models.BooleanField(_(u'Highlighted'), blank=True)
+    status = models.BooleanField(_(u'Status'), default=True)
     thread_id = models.CharField(_(u'Disqus thread id'), max_length=32,
-                                 blank=True) # DISQUS
+                                 blank=True)  # DISQUS
     lang = models.CharField(_(u'Language of the post'), max_length=32,
                             blank=True, null=True)
 
@@ -68,17 +69,17 @@ class Post(models.Model):
 class Comments(models.Model):
 
     """
-    Modelo que define comentarios (DISQUS).
+    Comment model (Disqus integration required)
     """
 
-    comment_id = models.CharField(max_length=32)
-    thread_id = models.CharField(max_length=32)
-    thread_link = models.CharField(max_length=200)
-    forum_id = models.CharField(max_length=32)
-    body = models.TextField()
-    author_name = models.CharField(max_length=200)
-    author_email = models.CharField(max_length=200)
-    author_url = models.CharField(max_length=200)
+    comment_id = models.CharField(_(u'Comment id'), max_length=32)
+    thread_id = models.CharField(_(u'Thread id'), max_length=32)
+    thread_link = models.CharField(_(u'Thread link'), max_length=200)
+    forum_id = models.CharField(_(u'Forum id'), max_length=32)
+    body = models.TextField(_(u'Comment'))
+    author_name = models.CharField(_(u'Author name'), max_length=200)
+    author_email = models.CharField(_(u'Author email'), max_length=200)
+    author_url = models.CharField(_(u'Author url'), max_length=200)
     date = models.DateTimeField()
 
     def __unicode__(self):
